summaryrefslogtreecommitdiffstats
path: root/unix/tkUnixEmbed.c
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2022-02-01 21:50:55 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2022-02-01 21:50:55 (GMT)
commit1ebb0c9d23b20f48bb8d5cc30f30532c99823731 (patch)
tree639f805d8747720a68d33f6fb1db835bfaf70bee /unix/tkUnixEmbed.c
parent0bffbe8dfe9cd138fc970a3b8d026558f2f57847 (diff)
downloadtk-1ebb0c9d23b20f48bb8d5cc30f30532c99823731.zip
tk-1ebb0c9d23b20f48bb8d5cc30f30532c99823731.tar.gz
tk-1ebb0c9d23b20f48bb8d5cc30f30532c99823731.tar.bz2
Fix Tk_Get3BorderColors() signature. Add documentation, created by René Zaumseil
Diffstat (limited to 'unix/tkUnixEmbed.c')
-rw-r--r--unix/tkUnixEmbed.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/unix/tkUnixEmbed.c b/unix/tkUnixEmbed.c
index 8881ec5..3057729 100644
--- a/unix/tkUnixEmbed.c
+++ b/unix/tkUnixEmbed.c
@@ -698,7 +698,7 @@ EmbedSendConfigure(
* this function will return either one, given the other.
*
* Results:
* If winPtr is a container, the return value is the token for the
* embedded window, and vice versa. If the "other" window isn't in this
* process, NULL is returned.
*
@@ -710,7 +710,7 @@ EmbedSendConfigure(
Tk_Window
Tk_GetOtherWindow(
- Tk_Window winPtr) /* Tk's structure for a container or embedded
+ Tk_Window tkwin) /* Tk's structure for a container or embedded
* window. */
{
Container *containerPtr;
@@ -720,9 +720,9 @@ Tk_GetOtherWindow(
for (containerPtr = tsdPtr->firstContainerPtr;
containerPtr != NULL;
containerPtr = containerPtr->nextPtr) {
- if ((Tk_Window)containerPtr->embeddedPtr == winPtr) {
+ if ((Tk_Window)containerPtr->embeddedPtr == tkwin) {
return (Tk_Window)containerPtr->parentPtr;
- } else if ((Tk_Window)containerPtr->parentPtr == winPtr) {
+ } else if ((Tk_Window)containerPtr->parentPtr == tkwin) {
return (Tk_Window)containerPtr->embeddedPtr;
}
}
@@ -698,7 +698,7 @@ EmbedSendConfigure(
*
* Results:
- * If winPtr is a container, the return value is the token for the
+ * If tkwin is a container, the return value is the token for the
* embedded window, and vice versa. If the "other" window isn't in this
* process, NULL is returned.